@@ -38,19 +38,21 @@ sub index :Path :Args(0) {
     $c->res->body($form->render);
 }
 
-=head2 image
+=head2 test
 
 returns the image belonging to the current captcha
 
 =cut
 
-sub image :Local{
+sub image : Local {
     my ( $self, $c ) = @_;
     my $captcha = $c->session->{captcha};
-    $c->res->content_type($captcha->{type});
-    my $filename = "captcha." . $captcha->{type};
-    $c->res->header('Content-Disposition', qq[attachment; filename=$filename]);
-    $c->res->body($captcha->{image});
+    $c->response->body($captcha->{image});
+    $c->response->content_type('image/'. $captcha->{type});
+    $c->res->headers->expires( time() );
+    $c->res->headers->header( 'Last-Modified' => HTTP::Date::time2str );
+    $c->res->headers->header( 'Pragma'        => 'no-cache' );
+    $c->res->headers->header( 'Cache-Control' => 'no-cache' );
 }
 
 sub get_rnd :Local{
